# for DocBook documents.

UNAME!=uname -s

NSGMLS?=	onsgmls

.if ${UNAME} == NetBSD
PREFIX?=	/usr/pkg
SGML_PREFIX?=	${PREFIX}/share/sgml
XML_PREFIX?=	${PREFIX}/share/xml
XSL_PREFIX?=	${PREFIX}/share/xsl
XML_DECL?=	${SGML_PREFIX}/docbook/dsssl/modular/dtds/decls/xml.dcl
DBX_CATALOG?=	${SGML_PREFIX}/docbook/4.2/catalog
DBX_DTD?=	${XML_PREFIX}/docbook/docbookx.dtd
DBX_XSL_HTML?=	${XSL_PREFIX}/docbook/html/docbook.xsl
DBX_XSL_HTMLCHUNK?=	${XSL_PREFIX}/docbook/html/chunk.xsl
.elif ${UNAME} == FreeBSD || ${UNAME} == OpenBSD
PREFIX?=	/usr/local
SGML_PREFIX?=	${PREFIX}/share/sgml
XML_PREFIX?=	${PREFIX}/share/xml
XSL_PREFIX?=	${PREFIX}/share/xsl
XML_DECL?=	${SGML_PREFIX}/docbook/dsssl/modular/dtds/decls/xml.dcl
DBX_CATALOG?=	${XML_PREFIX}/docbook/4.2/catalog
DBX_DTD?=	${XML_PREFIX}/docbook/4.2/docbookx.dtd
DBX_XSL_HTML?=	${XSL_PREFIX}/docbook/html/docbook.xsl
DBX_XSL_HTMLCHUNK?=	${XSL_PREFIX}/docbook/html/chunk.xsl
.endif

CATALOGS+= share/catalog
CATALOGS+= ${WEB_PREFIX}/guide/share/dsl/catalog
CATALOGS+= ${SGML_PREFIX}/catalog
CATALOGS+= ${SGML_PREFIX}/docbook/dsssl/modular/catalog
CATALOGS+= ${DBX_CATALOG}

SGML_CATALOGS= ${CATALOGS:S/^/-c /g}

PS2PDF?=	ps2pdf
DVIPS?=		dvips
SED?=		/usr/bin/sed
CAT?=		/bin/cat

TIDY_BIN?=	${PREFIX}/bin/tidy
.if ${UNAME} == NetBSD || ${UNAME} == OpenBSD
TIDY_OPTS?= -i -m -raw -f /dev/null -asxml ${TIDYFLAGS}
.elif ${UNAME} == FreeBSD
TIDY_OPTS?= -i -m -raw -preserve -f /dev/null -asxml ${TIDYFLAGS}
.endif
TIDY?=		${TIDY_BIN} ${TIDY_OPTS} ${TIDY_FLAGS}

FORMATS?=	html

MANIFEST?=	HTML.manifest
HTML_INDEX?=	index.html

CLEANFILES+=	${MANIFEST}
CLEANFILES+=	*~ core *.core
CLEANFILES+=	*.rtf
CLEANFILES+=	*.html
CLEANFILES+=	*.fot
CLEANFILES+=	*.log *.aux *.dvi *.tex *.out
CLEANFILES+=	*.ps *.pdf

CLEANFILES+=	default.xml default.xsl master.xsl
CLEANFILES+=	default-chunk.xml default-chunk.xsl master-chunk.xsl
CLEANFILES+=	.sxerr

all: build

.for F in ${FORMATS}
build: build-${F}
.endfor

build-html: ${DOC}.html
build-html-split: ${HTML_INDEX}
build-ps: ${DOC}.ps
build-pdf: ${DOC}.pdf

clean:
	-rm -f `cat ${MANIFEST}`
	rm -f ${CLEANFILES}

.SUFFIXES:
.SUFFIXES: .tex .xml .sgml .html .rtf .ps .pdf

.PHONY: all clean install
.PHONY: build-html build-ps build-pdf

STYLE_TYPE?= dsssl
.if ${STYLE_TYPE} == dsssl
.include "${WEB_PREFIX}/guide/share/mk/doc.docbook.dsssl.mk"
.else
.include "${WEB_PREFIX}/guide/share/mk/doc.docbook.xsl.mk"
.endif
